window.Gleam.initSearch([{"doc":"effect","title":"effect","content":"# effect\n\n[![Package Version](https://img.shields.io/hexpm/v/effect)](https://hex.pm/packages/effect)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/effect/)\n\n```sh\ngleam add effect@1.1.0\n```\n```gleam\nimport effect\n\npub fn main() {\n  let google: Effect(Result(String, Error)) = {\n    use uri &lt;- effect.try_replace_error(\n      uri.parse(&quot;https://www.google.com&quot;),\n      UriParse,\n    )\n    use req &lt;- effect.try_replace_error(request.from_uri(uri), UriParse)\n    use res &lt;- effect.try_await_map_error(fetch.send(req), Fetch)\n    use text &lt;- effect.try_await_map_error(fetch.read_text_body(res), Fetch)\n\n    text.body |&gt; Ok |&gt; effect.dispatch\n  }\n\n  use res &lt;- effect.perform(google)\n  case res {\n    Ok(body) -&gt; io.println(body)\n    Error(e) -&gt; e |&gt; string.inspect |&gt; io.println_error\n  }\n}\n```\n\nFurther documentation can be found at &lt;https://hexdocs.pm/effect&gt;.\n\n## Development\n\n```sh\ngleam run   # Run the project\ngleam test  # Run the tests\n```\n","url":"index.html"},{"doc":"effect","title":"Effect","content":"pub opaque type Effect(msg)\n The `Effect` type represents a description of side effects as data. Each\n effect specifies:\n 1. The operations to perform\n 2. The type of messages that will be sent back to your program\n\n\nSynonyms:\neffect.Effect\neffect Effect","url":"effect.html#Effect"},{"doc":"effect","title":"dispatch","content":"pub fn dispatch(value: a) -&gt; Effect(a)\n Convert a value into an effect that will dispatch that value when performed.\n\n \n value\n |&gt; dispatch\n |&gt; perform(handle_value)\n \nSynonyms:\neffect.dispatch\neffect dispatch","url":"effect.html#dispatch"},{"doc":"effect","title":"from","content":"pub fn from(effect: fn(fn(a) -&gt; Nil) -&gt; Nil) -&gt; Effect(a)\n Create a custom effect from a function that takes a dispatch callback.\n The dispatch callback can be used to send messages back to your program.\n\n \n from(fn(dispatch) {\n   dispatch(MyMessage)\n })\n \nSynonyms:\neffect.from\neffect from","url":"effect.html#from"},{"doc":"effect","title":"map","content":"pub fn map(effect: Effect(a), f: fn(a) -&gt; b) -&gt; Effect(b)\n Transform the messages produced by an effect. This is useful when you need\n to adapt effects from one part of your program to work with another.\n\n \n effect\n |&gt; map(fn(msg) { TransformedMessage(msg) })\n \nSynonyms:\neffect.map\neffect map","url":"effect.html#map"},{"doc":"effect","title":"map_result","content":"pub fn map_result(\n  effect: Effect(Result(a, b)),\n  f: fn(a) -&gt; Effect(Result(c, b)),\n) -&gt; Effect(Result(c, b))\n Transform an effect containing a Result by providing a function that operates on\n the success value and returns another Result-containing effect. This is useful\n for chaining effects where each step can potentially fail. Errors from either\n the input effect or the transformation function will short-circuit the chain.\n\n \n use response &lt;- map_result(initial_effect)\n handle_response(response)\n \nSynonyms:\neffect.map_result\neffect map_result","url":"effect.html#map_result"},{"doc":"effect","title":"none","content":"pub fn none() -&gt; Effect(a)\n Create an effect that does nothing. This is useful when you need to return\n an effect but don&#39;t actually want to perform any operations.\n\nSynonyms:\neffect.none\neffect none","url":"effect.html#none"},{"doc":"effect","title":"param","content":"pub fn param(f: fn(a) -&gt; b) -&gt; fn(a) -&gt; b\n Helper function similar to clip&#39;s parameter function. Provides an alternative\n syntax for building curried functions. The following are equivalent:\n\n \n fn(a) { fn(b) { thing(a, b) } }\n\n {\n   use a &lt;- param\n   use b &lt;- param\n   thing(a, b)\n }\n \n\n Mostly used internally.\n\nSynonyms:\neffect.param\neffect param","url":"effect.html#param"},{"doc":"effect","title":"perform","content":"pub fn perform(effect: Effect(a), dispatch: fn(a) -&gt; b) -&gt; Nil\n Run an effect by providing a dispatch function that will receive any\n messages produced by the effect.\n\n \n effect\n |&gt; perform(fn(msg) {\n   case msg {\n     Ok(data) -&gt; handle_success(data)\n     Error(e) -&gt; handle_error(e)\n   }\n })\n \nSynonyms:\neffect.perform\neffect perform","url":"effect.html#perform"},{"doc":"effect","title":"try","content":"pub fn try(\n  res: Result(a, b),\n  f: fn(a) -&gt; Effect(Result(c, b)),\n) -&gt; Effect(Result(c, b))\n Handle a Result by providing a function that produces an effect for the\n success case. Errors are automatically converted into effects.\n\n \n use data &lt;- try(parse_data())\n process_data(data)\n \nSynonyms:\neffect.try\neffect try","url":"effect.html#try"},{"doc":"effect","title":"try_await","content":"pub fn try_await(\n  pres: Promise(Result(a, b)),\n  f: fn(a) -&gt; Effect(Result(c, b)),\n) -&gt; Effect(Result(c, b))\n Handle a Promise containing a Result by providing a function that produces\n an effect for the success case. This is particularly useful for handling\n async operations like HTTP requests.\n\n \n use response &lt;- try_await(fetch.send(request))\n process_response(response)\n \nSynonyms:\neffect.try_await\neffect try_await","url":"effect.html#try_await"},{"doc":"effect","title":"try_await_map_error","content":"pub fn try_await_map_error(\n  pres: Promise(Result(a, b)),\n  map_error: fn(b) -&gt; c,\n  f: fn(a) -&gt; Effect(Result(d, c)),\n) -&gt; Effect(Result(d, c))\n Similar to `try_await` but allows mapping error values before they&#39;re\n dispatched. This is commonly used when you want to wrap external errors\n in your own error type.\n\n \n use response &lt;- try_await_map_error(\n   fetch.send(request),\n   fn(e) { NetworkError(e) }\n )\n process_response(response)\n \nSynonyms:\neffect.try_await_map_error\neffect try_await_map_error","url":"effect.html#try_await_map_error"},{"doc":"effect","title":"try_await_replace_error","content":"pub fn try_await_replace_error(\n  pres: Promise(Result(a, b)),\n  e: c,\n  f: fn(a) -&gt; Effect(Result(d, c)),\n) -&gt; Effect(Result(d, c))\n Similar to `try_await` but allows replacing error values before they&#39;re\n dispatched. This is commonly used when you want to wrap external errors\n in your own error type.\n\n \n use response &lt;- try_await_replace_error(\n   fetch.send(request),\n   NetworkError,\n )\n process_response(response)\n \nSynonyms:\neffect.try_await_replace_error\neffect try_await_replace_error","url":"effect.html#try_await_replace_error"},{"doc":"effect","title":"try_map_error","content":"pub fn try_map_error(\n  res: Result(a, b),\n  map_error: fn(b) -&gt; c,\n  f: fn(a) -&gt; Effect(Result(d, c)),\n) -&gt; Effect(Result(d, c))\n Similar to `try` but allows mapping error values before they&#39;re dispatched.\n You can emulate this using `try` and `result.map_error`.\n\n \n use response &lt;- try_map_error(\n   fetch.send(request),\n   fn(e) { NetworkError(e) }\n )\n process_response(response)\n \nSynonyms:\neffect.try_map_error\neffect try_map_error","url":"effect.html#try_map_error"},{"doc":"effect","title":"try_replace_error","content":"pub fn try_replace_error(\n  res: Result(a, b),\n  e: c,\n  f: fn(a) -&gt; Effect(Result(d, c)),\n) -&gt; Effect(Result(d, c))\n Similar to `try` but allows replacing error values before they&#39;re dispatched.\n You can emulate this using `try` and `result.replace_error`.\n\n \n use response &lt;- try_replace_error(\n   fetch.send(request),\n   NetworkError,\n )\n process_response(response)\n \nSynonyms:\neffect.try_replace_error\neffect try_replace_error","url":"effect.html#try_replace_error"},{"doc":"effect","title":"effect","content":"","url":"effect.html"}]);